@@ -77,7 +77,7 @@ class CCalcRun(QtWidgets.QMainWindow):
     def stop_calc(self):
         if self.d_info is not None:
             self.d_info["stop"] = True
-            self.btn.setText("Wait a little.")
+            self.btn.setText("Wait a second.")
             self.btn.setEnabled(False)
 
 
@@ -363,7 +363,6 @@ class CBuilder(QtWidgets.QMainWindow):
         self.move(screen.width() / 10, screen.height() / 20)
         self.resize(screen.width() * 8. / 10., screen.height() * 14. / 16.)
 
-
     def calc_is_finished(self) -> NoReturn:
         """After calculations."""
         m_box = QtWidgets.QMessageBox(self)
@@ -377,7 +376,12 @@ class CBuilder(QtWidgets.QMainWindow):
         # self.load_globaln()
     def load_globaln(self) -> NoReturn:
         """Read globaln from file."""
-        obj = file_to_globaln(self.f_file)
+        try:
+            obj = file_to_globaln(self.f_file)
+        except Exception as e:
+            obj = RhoChi()
+            s_out = f"ERROR at file reading: \n{e:}"
+            self.wconsole.setText(s_out)
         self.wpanel.object = obj
         self.form_wpanel()
         self.form_wstackedwidget(obj)
