@@ -184,7 +184,7 @@ def dock_mem(obj: MEM, thread: QtCore.QThread):
     if (flag_crystals & flag_experiments & obj.is_defined()):
         if flag_crystals:
             crystal = crystals[0]
-            if crystal.atom_electron_configuration is None:
+            if not(crystal.is_attribute("atom_electron_configuration")):
                 cb_1 = QtWidgets.QPushButton(
                     "Create AtomElectronConfiguration")
                 cb_1.clicked.connect(lambda: crystal.add_items([
@@ -316,34 +316,65 @@ def dock_pd(obj: Pd, thread: QtCore.QThread):  # FIXME: dock_peak should be adde
         - dock_refine_ls
         - dock_peak
     """
-    f_proc, f_meas, f_peak = False, False, False
-    proc, meas = None, None
-    meas = obj.pd_meas
-    f_meas = meas is not None
-    chi2 = obj.chi2
-    f_chi2 = chi2 is not None
-    refine_ls = obj.refine_ls
-    f_refine_ls = refine_ls is not None
+    try:
+        meas = obj.pd_meas
+        f_meas = True
+    except AttributeError:
+        f_meas = False
+    try:
+        chi2 = obj.chi2
+        f_chi2 = True
+    except AttributeError:
+        f_chi2 = False
+    try:
+        refine_ls = obj.refine_ls
+        f_refine_ls = True
+    except AttributeError:
+        f_refine_ls = False
+    try:
+        proc = obj.pd_proc
+        f_proc = True
+    except AttributeError:
+        f_proc = False
+    try:
+        phase = obj.phase
+        f_phase = True
+    except AttributeError:
+        f_phase = False
 
-    proc = obj.pd_proc
-    f_proc = proc is not None
-    phase = obj.phase
-    f_phase = phase is not None
     l_pd_peak = []
     if f_phase:
         for item in phase.items:
-            pd_peak = getattr(obj, f"pd_peak_{item.label.lower():}")
-            if pd_peak is not None:
+            try:
+                pd_peak = getattr(obj, f"pd_peak_{item.label.lower():}")
                 l_pd_peak.append(pd_peak)
+            except AttributeError:
+                pass
 
     docks = []
 
-    f_setup = obj.setup is not None
-    f_pd_instr_resolution = obj.pd_instr_resolution is not None
-    f_pd_background = obj.pd_background is not None
-    f_range = obj.range is not None
+    try:
+        setup = obj.setup
+        f_setup = True
+    except AttributeError:
+        f_setup = False
+    try:
+        pd_instr_resolution = obj.pd_instr_resolution
+        f_pd_instr_resolution = True
+    except AttributeError:
+        f_pd_instr_resolution = False
+    try:
+        pd_background = obj.pd_background
+        f_pd_background = True
+    except AttributeError:
+        f_pd_background = False
+    try:
+        range_ = obj.range
+        f_range = True
+    except AttributeError:
+        f_range = False
     # f_diffrn_radiation = obj.diffrn_radiation is not None
-    
+
     if not(f_chi2 & f_meas & f_setup & f_pd_instr_resolution & f_phase &
            f_pd_background & f_range):
         layout_actions = QtWidgets.QHBoxLayout()
@@ -412,7 +443,8 @@ def dock_pd(obj: Pd, thread: QtCore.QThread):  # FIXME: dock_peak should be adde
         #     cb_1 = QtWidgets.QPushButton("Add diffrn_radiation")
         #     cb_1.setSizePolicy(QtWidgets.QSizePolicy.Expanding,
         #                        QtWidgets.QSizePolicy.Expanding)
-        #     cb_1.clicked.connect(lambda: add_items(obj, [DiffrnRadiation()], thread))
+        #     cb_1.clicked.connect(lambda: add_items(obj, [DiffrnRadiation()],
+        #                          thread))
         #     layout_actions.addWidget(cb_1)
         layout_actions.addStretch(1)
         widget_actions = QtWidgets.QWidget()
@@ -436,17 +468,23 @@ def dock_pd(obj: Pd, thread: QtCore.QThread):  # FIXME: dock_peak should be adde
 def dock_proc(obj: PdProcL, l_pd_peak: List[PdPeakL]):
     """Form dock for PdProc object."""
     np_x_1 = numpy.array(obj.ttheta, dtype=float)
-    np_y_u_1 = numpy.array(obj.intensity_up, dtype=float)
     # np_y_su_1 = numpy.array(obj.intensity_up_sigma, dtype=float)
-    np_y_d_1 = numpy.array(obj.intensity_down, dtype=float)
     # np_y_sd_1 = numpy.array(obj.intensity_down_sigma, dtype=float)
     # np_y_b_1 = numpy.array(obj.intensity_bkg_calc, dtype=float)
     # np_y_u_2 = numpy.array(obj.intensity_up_total, dtype=float)
     # np_y_d_2 = numpy.array(obj.intensity_down_total, dtype=float)
     np_y_s_1 = numpy.array(obj.intensity, dtype=float)
     np_y_ss_1 = numpy.array(obj.intensity_sigma, dtype=float)
-    np_y_m_1 = np_y_u_1 - np_y_d_1
+    try:
+        np_y_u_1 = numpy.array(obj.intensity_up, dtype=float)
+        np_y_d_1 = numpy.array(obj.intensity_down, dtype=float)
+        np_y_m_1 = np_y_u_1 - np_y_d_1
+        flag_polaraized = True
+    except AttributeError:
+        np_y_m_1 = 0*np_y_s_1
+        flag_polaraized = False
     np_y_sm_1 = np_y_ss_1
+
     np_y_s_2 = numpy.array(obj.intensity_total, dtype=float)
     np_y_m_2 = numpy.array(obj.intensity_diff_total, dtype=float)
 
@@ -471,83 +509,96 @@ def dock_proc(obj: PdProcL, l_pd_peak: List[PdPeakL]):
     p2.addItem(pg.PlotCurveItem(x=np_x_1, y=np_y_s_1-np_y_s_2,
                                 pen=pg_pen_black_thick))
 
-    vb_2 = pg.ViewBox()
-    vb_2.setMouseMode(vb_2.RectMode)
-    widget_2 = pg.PlotWidget(viewBox=vb_2)
-    p3 = widget_2.plotItem
-    p4 = add_2nd_axis_to_plot(p3, label_axis_1="Intensity (a.u.)",
-                              label_axis_2="Difference")
-    err1 = pg.ErrorBarItem(x=np_x_1, y=np_y_m_1, top=np_y_sm_1,
-                           bottom=np_y_ss_1, beam=0.5)
-    p3.plot(x=np_x_1, y=np_y_m_1, name="exp", title="model",
-            symbol='o', pen={'color': 0.8, 'width': 2})
-    p3.plot(x=np_x_1, y=np_y_m_2, name="model", title="model",
-            pen=pg_pen_black)
-    p3.addItem(err1)
-    p4.addItem(pg.PlotCurveItem(x=np_x_1, y=np_y_m_1-np_y_m_2,
-                                pen=pg_pen_black_thick))
-
     [x_range_12, y_range_12] = p1.viewRange()
     y_range = y_range_12[1]-y_range_12[0]
     p2.setRange(yRange=(-0.15*y_range, 0.85*y_range))
-    [x_range_34, y_range_34] = p3.viewRange()
-    y_range = y_range_34[1]-y_range_34[0]
-    p3.setYRange(-0.50*y_range, 0.50*y_range)
-    p4.setRange(yRange=(-0.15*y_range, 0.85*y_range))
 
     yrange_2 = p2.viewRange()[1]
     ysize_2 = 0.05*(yrange_2[1]-yrange_2[0])
     yshift_2 = 0.5*0.5*0.5*ysize_2*len(l_pd_peak)
-    yrange_4 = p4.viewRange()[1]
-    ysize_4 = 0.05*(yrange_4[1]-yrange_4[0])
-    yshift_4 = 0.5*ysize_4*len(l_pd_peak)
+
+    if flag_polaraized:
+
+        vb_2 = pg.ViewBox()
+        vb_2.setMouseMode(vb_2.RectMode)
+        widget_2 = pg.PlotWidget(viewBox=vb_2)
+        p3 = widget_2.plotItem
+        p4 = add_2nd_axis_to_plot(p3, label_axis_1="Intensity (a.u.)",
+                                  label_axis_2="Difference")
+        err1 = pg.ErrorBarItem(x=np_x_1, y=np_y_m_1, top=np_y_sm_1,
+                               bottom=np_y_ss_1, beam=0.5)
+        p3.plot(x=np_x_1, y=np_y_m_1, name="exp", title="model",
+                symbol='o', pen={'color': 0.8, 'width': 2})
+        p3.plot(x=np_x_1, y=np_y_m_2, name="model", title="model",
+                pen=pg_pen_black)
+        p3.addItem(err1)
+        p4.addItem(pg.PlotCurveItem(x=np_x_1, y=np_y_m_1-np_y_m_2,
+                                    pen=pg_pen_black_thick))
+
+        [x_range_34, y_range_34] = p3.viewRange()
+        y_range = y_range_34[1]-y_range_34[0]
+        p3.setYRange(-0.50*y_range, 0.50*y_range)
+        p4.setRange(yRange=(-0.15*y_range, 0.85*y_range))
+
+        yrange_4 = p4.viewRange()[1]
+        ysize_4 = 0.05*(yrange_4[1]-yrange_4[0])
+        yshift_4 = 0.5*ysize_4*len(l_pd_peak)
+
     for pd_peak in l_pd_peak:
         numpy_ttheta = numpy.array(pd_peak.ttheta, dtype=float)
         np_zero = 0.*numpy_ttheta
         ind_miller_2 = pg.ErrorBarItem(
             x=numpy_ttheta, y=np_zero+yshift_2, top=np_zero+yshift_2+ysize_2,
             bottom=np_zero-yshift_2+ysize_2, beam=0.0)
-        ind_miller_4 = pg.ErrorBarItem(
-            x=numpy_ttheta, y=np_zero+yshift_4, top=np_zero+yshift_4+ysize_4,
-            bottom=np_zero-yshift_4+ysize_4, beam=0.0)
         p2.addItem(ind_miller_2)
-        p4.addItem(ind_miller_4)
         yshift_2 -= 0.5*ysize_2
-        yshift_4 -= 1.0*ysize_4
+        if flag_polaraized:
+            ind_miller_4 = pg.ErrorBarItem(
+                x=numpy_ttheta, y=np_zero+yshift_4,
+                top=np_zero+yshift_4+ysize_4,
+                bottom=np_zero-yshift_4+ysize_4, beam=0.0)
+            p4.addItem(ind_miller_4)
+            yshift_4 -= 1.0*ysize_4
 
-
-    dock_1 = pg_da.Dock("Sum", widget=widget, autoOrientation=False)
-    dock_2 = pg_da.Dock("Difference", widget=widget_2, autoOrientation=False)
-
-    return (dock_1, dock_2, )
+    if flag_polaraized:
+        dock_1 = pg_da.Dock("Sum", widget=widget, autoOrientation=False)
+        dock_2 = pg_da.Dock("Difference", widget=widget_2,
+                            autoOrientation=False)
+        res = (dock_1, dock_2, )
+    else:
+        dock_1 = pg_da.Dock("Intensity", widget=widget, autoOrientation=False)
+        res = (dock_1, )
+    return res
 
 
 def dock_meas(obj: PdMeasL):
     """Form docks for PdMeasL object."""
     np_x_1 = numpy.array(obj.ttheta, dtype=float)
-    np_y_u_1 = numpy.array(obj.intensity_up, dtype=float)
-    np_y_su_1 = numpy.array(obj.intensity_up_sigma, dtype=float)
-    np_y_d_1 = numpy.array(obj.intensity_down, dtype=float)
-    np_y_sd_1 = numpy.array(obj.intensity_down_sigma, dtype=float)
+    try:
+        np_y_u_1 = numpy.array(obj.intensity_up, dtype=float)
+        np_y_su_1 = numpy.array(obj.intensity_up_sigma, dtype=float)
+        np_y_d_1 = numpy.array(obj.intensity_down, dtype=float)
+        np_y_sd_1 = numpy.array(obj.intensity_down_sigma, dtype=float)
+        flag_polaraized = True
+    except AttributeError:
+        flag_polaraized = False
 
-    if numpy.all(numpy.isnan(np_y_u_1)):
-        np_y_s_1 = numpy.array(obj.intensity, dtype=float)
-        np_y_ss_1 = numpy.array(obj.intensity_sigma, dtype=float)
-        np_y_m_1 = 0*np_y_s_1
-        np_y_sm_1 = np_y_ss_1
-    else:
+    if flag_polaraized:
         np_y_s_1 = np_y_u_1 + np_y_d_1
         np_y_ss_1 = numpy.sqrt(numpy.square(np_y_su_1) +
                                numpy.square(np_y_sd_1))
         np_y_m_1 = np_y_u_1 - np_y_d_1
         np_y_sm_1 = np_y_ss_1
+    else:
+        np_y_s_1 = numpy.array(obj.intensity, dtype=float)
+        np_y_ss_1 = numpy.array(obj.intensity_sigma, dtype=float)
+        np_y_m_1 = 0*np_y_s_1
+        np_y_sm_1 = np_y_ss_1
 
     vb_1 = pg.ViewBox()
     vb_1.setMouseMode(vb_1.RectMode)
     widget = pg.PlotWidget(viewBox=vb_1)
     p1 = widget.plotItem
-    p2 = add_2nd_axis_to_plot(p1, label_axis_1="Intensity (a.u.)",
-                              label_axis_2="Intensity (a.u.)")
     err_s = pg.ErrorBarItem(x=np_x_1, y=np_y_s_1, top=np_y_ss_1,
                             bottom=np_y_ss_1, beam=0.5)
     err_m = pg.ErrorBarItem(x=np_x_1, y=np_y_m_1, top=np_y_sm_1,
@@ -555,37 +606,46 @@ def dock_meas(obj: PdMeasL):
     p1.plot(x=np_x_1, y=np_y_s_1, name="sum", title="Sum",
             symbol='o', pen={'color': 0.8, 'width': 2})
     p1.addItem(err_s)
-    p2.addItem(pg.PlotCurveItem(x=np_x_1, y=np_y_m_1, name="diff",
-                                title="Difference", pen=pg_pen_black_thick))
-    p2.addItem(pg.ScatterPlotItem(x=np_x_1, y=np_y_m_1,
-                                  symbol='o', pen={'color': 0.8, 'width': 2}))
-    p2.addItem(err_m)
-    [x_range_12, y_range_12] = p1.viewRange()
-    y_range = y_range_12[1]-y_range_12[0]
-    p2.setRange(yRange=(-0.25*y_range, 0.75*y_range))
-    
-    vb_2 = pg.ViewBox()
-    vb_2.setMouseMode(vb_2.RectMode)
-    widget_2 = pg.PlotWidget(viewBox=vb_2)
-    p3 = widget_2.plotItem
-    p4 = add_2nd_axis_to_plot(p3, label_axis_1="Intensity (a.u.)",
-                              label_axis_2="Intensity (a.u.)")
-    err_u = pg.ErrorBarItem(x=np_x_1, y=np_y_u_1, top=np_y_su_1,
-                            bottom=np_y_su_1, beam=0.5)
-    err_d = pg.ErrorBarItem(x=np_x_1, y=np_y_d_1, top=np_y_sd_1,
-                            bottom=np_y_sd_1, beam=0.5)
-    p3.plot(x=np_x_1, y=np_y_u_1, name="up", title="Up",
-            symbol='o', pen={'color': 0.8, 'width': 2})
-    p3.addItem(err_u)
-    p4.addItem(pg.PlotCurveItem(x=np_x_1, y=np_y_d_1, name="down",
-                                title="Down", pen=pg_pen_black_thick))
-    p4.addItem(pg.ScatterPlotItem(x=np_x_1, y=np_y_d_1,
-                                  symbol='o', pen={'color': 0.8, 'width': 2}))
-    p4.addItem(err_d)
+
+    if flag_polaraized:
+        p2 = add_2nd_axis_to_plot(p1, label_axis_1="Intensity (a.u.)",
+                                  label_axis_2="Intensity (a.u.)")
+        p2.addItem(pg.PlotCurveItem(
+            x=np_x_1, y=np_y_m_1, name="diff", title="Difference",
+            pen=pg_pen_black_thick))
+        p2.addItem(pg.ScatterPlotItem(
+            x=np_x_1, y=np_y_m_1, symbol='o', pen={'color': 0.8, 'width': 2}))
+        p2.addItem(err_m)
+        [x_range_12, y_range_12] = p1.viewRange()
+        y_range = y_range_12[1]-y_range_12[0]
+        p2.setRange(yRange=(-0.25*y_range, 0.75*y_range))
 
     dock_1 = pg_da.Dock("Sum/Diff.", widget=widget, autoOrientation=False)
-    dock_2 = pg_da.Dock("Up/Down", widget=widget_2, autoOrientation=False)
-    return (dock_1, dock_2, )
+
+    if flag_polaraized:
+        vb_2 = pg.ViewBox()
+        vb_2.setMouseMode(vb_2.RectMode)
+        widget_2 = pg.PlotWidget(viewBox=vb_2)
+        p3 = widget_2.plotItem
+        p4 = add_2nd_axis_to_plot(p3, label_axis_1="Intensity (a.u.)",
+                                  label_axis_2="Intensity (a.u.)")
+        err_u = pg.ErrorBarItem(x=np_x_1, y=np_y_u_1, top=np_y_su_1,
+                                bottom=np_y_su_1, beam=0.5)
+        err_d = pg.ErrorBarItem(x=np_x_1, y=np_y_d_1, top=np_y_sd_1,
+                                bottom=np_y_sd_1, beam=0.5)
+        p3.plot(x=np_x_1, y=np_y_u_1, name="up", title="Up",
+                symbol='o', pen={'color': 0.8, 'width': 2})
+        p3.addItem(err_u)
+        p4.addItem(pg.PlotCurveItem(x=np_x_1, y=np_y_d_1, name="down",
+                                    title="Down", pen=pg_pen_black_thick))
+        p4.addItem(pg.ScatterPlotItem(x=np_x_1, y=np_y_d_1,
+                                      symbol='o', pen={'color': 0.8, 'width': 2}))
+        p4.addItem(err_d)
+        dock_2 = pg_da.Dock("Up/Down", widget=widget_2, autoOrientation=False)
+        res = (dock_1, dock_2, )
+    else:
+        res = (dock_1, )
+    return res
 
 
 def dock_chi2(obj: Chi2):
@@ -593,25 +653,25 @@ def dock_chi2(obj: Chi2):
     docks = []
     layout = QtWidgets.QGridLayout()
     cb_s = QtWidgets.QCheckBox("sum")
-    if obj.sum is not None:
+    if obj.is_attribute("sum"):
         cb_s.setCheckState(2*int(obj.sum))
     cb_s.stateChanged.connect(lambda x: setattr(obj, "sum", bool(x/2)))
     layout.addWidget(cb_s, 0, 0)
 
     cb_m = QtWidgets.QCheckBox("diff")
-    if obj.diff is not None:
+    if obj.is_attribute("diff"):
         cb_m.setCheckState(2*int(obj.diff))
     cb_m.stateChanged.connect(lambda x: setattr(obj, "diff", bool(x/2)))
     layout.addWidget(cb_m, 1, 0)
 
     cb_u = QtWidgets.QCheckBox("up")
-    if obj.up is not None:
+    if obj.is_attribute("up"):
         cb_u.setCheckState(2*int(obj.up))
     cb_u.stateChanged.connect(lambda x: setattr(obj, "up", bool(x/2)))
     layout.addWidget(cb_u, 0, 1)
 
     cb_d = QtWidgets.QCheckBox("down")
-    if obj.down is not None:
+    if obj.is_attribute("down"):
         cb_d.setCheckState(2*int(obj.down))
     cb_d.stateChanged.connect(lambda x: setattr(obj, "down", bool(x/2)))
     layout.addWidget(cb_d, 1, 1)
@@ -626,8 +686,8 @@ def dock_chi2(obj: Chi2):
 def dock_refine_ls(obj: RefineLs):
     """Form docks for RefineLs object."""
     docks = []
-    if ((obj.number_reflns is not None) &
-            (obj.goodness_of_fit_all is not None)):
+    if ((obj.is_attribute("number_reflns")) &
+            (obj.is_attribute("goodness_of_fit_all"))):
         val_1, val_2 = obj.number_reflns, obj.goodness_of_fit_all
         text = f"Points: {val_1:}\nGoF: {val_2:.2f}"
         widget = QtWidgets.QLabel(text)
@@ -788,7 +848,9 @@ def dock_cell(obj:Cell):
         docks.append(dock_1)
     return tuple(docks)
 
-def dock_space_group(obj:SpaceGroup):
+
+def dock_space_group(obj: SpaceGroup):
+    """Docks for space_group."""
     docks = []
     s_str = obj.report_space_group()
     if s_str is not None:
@@ -798,7 +860,7 @@ def dock_space_group(obj:SpaceGroup):
         area.setWidget(widget)
 
         widget.setStyleSheet("background-color:white;")
-        #widget.setFont(QtGui.QFont("Courier", 12, QtGui.QFont.Bold))
+        # widget.setFont(QtGui.QFont("Courier", 12, QtGui.QFont.Bold))
         widget.setSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
         widget.setText(s_str)
 
@@ -806,10 +868,23 @@ def dock_space_group(obj:SpaceGroup):
         docks.append(dock_1)
     return tuple(docks)
 
-def dock_crystal(obj:Crystal, thread: QtCore.QThread):
+
+def dock_crystal(obj: Crystal, thread: QtCore.QThread):
+    """Docks for crystal."""
     docks = []
-    cell = obj.cell
-    space_group = obj.space_group
+    try:
+        cell = obj.cell
+    except AttributeError:
+        cell = None
+    try:
+        space_group = obj.space_group
+    except AttributeError:
+        space_group = None
+    try:
+        atom_site = obj.atom_site
+    except AttributeError:
+        atom_site = None
+
     if not obj.is_defined():
         layout_actions = QtWidgets.QHBoxLayout()
         if cell is None:
@@ -831,7 +906,7 @@ def dock_crystal(obj:Crystal, thread: QtCore.QThread):
                                                    [SpaceGroup(it_number=1)],
                                                    thread))
             layout_actions.addWidget(cb_1)
-        if obj.atom_site is None:
+        if atom_site is None:
             cb_1 = QtWidgets.QPushButton("Add atom site")
             cb_1.setSizePolicy(QtWidgets.QSizePolicy.Expanding,
                                 QtWidgets.QSizePolicy.Expanding)
@@ -871,31 +946,72 @@ def dock_crystal(obj:Crystal, thread: QtCore.QThread):
 def dock_pd2d(obj:Pd2d, thread: QtCore.QThread):
     f_proc, f_meas, f_bkgr, f_peak = False, False, False, False
     proc, meas, bkgr, peak = None, None, None, None
-    meas = obj.pd2d_meas
-    f_meas = meas is not None
-    bkgr = obj.pd2d_background
-    f_bkgr = bkgr is not None
-    chi2 = obj.chi2
-    f_chi2 = chi2 is not None
-    refine_ls = obj.refine_ls
-    f_refine_ls = refine_ls is not None
-
-    proc = obj.pd2d_proc
-    f_proc = proc is not None
+    try:
+        meas = obj.pd2d_meas
+        f_meas = True
+    except AttributeError:
+        f_meas = False
+    try:
+        bkgr = obj.pd2d_background
+        f_bkgr = True
+    except AttributeError:
+        f_bkgr = False
+    try:
+        chi2 = obj.chi2
+        f_chi2 = True
+    except AttributeError:
+        f_chi2 = False
+    try:
+        refine_ls = obj.refine_ls
+        f_refine_ls = True
+    except AttributeError:
+        f_refine_ls = False
+    try:
+        proc = obj.pd2d_proc
+        f_proc = True
+    except AttributeError:
+        f_proc = False
     l_pd2d_peak = []
-    phase = obj.phase
-    for item in phase.items:
-        pd2d_peak = getattr(obj, f"pd2d_peak_{item.label.lower():}")
-        if pd2d_peak is not None:
-            l_pd2d_peak.append(pd2d_peak)
+    try:
+        phase = obj.phase
+        f_phase = True
+    except AttributeError:
+        f_phase = False
+
+    if f_phase:
+        for item in phase.items:
+            try:
+                pd2d_peak = getattr(obj, f"pd2d_peak_{item.label.lower():}")
+                l_pd2d_peak.append(pd2d_peak)
+            except AttributeError:
+                pass
 
     docks = []
-
-    f_setup = obj.setup is not None
-    f_pd2d_instr_resolution = obj.pd2d_instr_resolution is not None
-    f_phase = obj.phase is not None
-    f_pd2d_background = obj.pd2d_background is not None
-    f_range = obj.range is not None
+    try:
+        setup = obj.setup
+        f_setup = True
+    except AttributeError:
+        f_setup = False
+    try:
+        pd2d_instr_resolution = obj.pd2d_instr_resolution
+        f_pd2d_instr_resolution = True
+    except AttributeError:
+        f_pd2d_instr_resolution = False
+    try:
+        phase = obj.phase
+        f_phase = True
+    except AttributeError:
+        f_phase = False
+    try:
+        pd2d_background = obj.pd2d_background 
+        f_pd2d_background = True
+    except AttributeError:
+        f_pd2d_background = False
+    try:
+        range_ = obj.range
+        f_range = True
+    except AttributeError:
+        f_range = False
     # f_diffrn_radiation = obj.diffrn_radiation is not None
 
     if not(f_chi2 & f_meas & f_setup & f_pd2d_instr_resolution & f_phase &
@@ -989,13 +1105,14 @@ def dock_pd2d(obj:Pd2d, thread: QtCore.QThread):
 
 def dock_pd2d_meas(obj:Pd2dMeas):
     docks = []
-    ttheta = obj.ttheta
-    phi = obj.phi
-    intensity_up = obj.intensity_up
-    intensity_up_sigma = obj.intensity_up_sigma
-    intensity_down = obj.intensity_down
-    intensity_down_sigma = obj.intensity_down_sigma
-    if ((intensity_up is None) & (intensity_down is None)):
+    try:
+        ttheta = obj.ttheta
+        phi = obj.phi
+        intensity_up = obj.intensity_up
+        intensity_up_sigma = obj.intensity_up_sigma
+        intensity_down = obj.intensity_down
+        intensity_down_sigma = obj.intensity_down_sigma
+    except AttributeError:
         return tuple(docks)
     int_s =  numpy.nan_to_num(intensity_up + intensity_down)
     int_m =  numpy.nan_to_num(intensity_up - intensity_down)
@@ -1071,32 +1188,30 @@ def dock_pd2d_meas(obj:Pd2dMeas):
 def dock_pd2d_proc(obj:Pd2dProc, l_pd2d_peak: List[Pd2dPeakL]):
     """Docks for pd2d_proc object."""
     docks = []
-    ttheta = obj.ttheta
-    phi = obj.phi
-
-    intensity_up = obj.intensity_up
-    intensity_up_sigma = obj.intensity_up_sigma
-    intensity_down = obj.intensity_down
-    intensity_down_sigma = obj.intensity_down_sigma
-    intensity_up_total = obj.intensity_up_total
-    intensity_down_total = obj.intensity_down_total
-
-    if ((intensity_up_total is None) & (intensity_down_total is None)):
+    try:
+        ttheta = obj.ttheta
+        phi = obj.phi
+        intensity_up = obj.intensity_up
+        intensity_up_sigma = obj.intensity_up_sigma
+        intensity_down = obj.intensity_down
+        intensity_down_sigma = obj.intensity_down_sigma
+        intensity_up_total = obj.intensity_up_total
+        intensity_down_total = obj.intensity_down_total
+    except AttributeError:
         return tuple(docks)
 
-
     z_sum = intensity_up_total+intensity_down_total
     z_sum_e = intensity_up+intensity_down
     z_sum_s_sq = (intensity_up_sigma)**2+(intensity_down_sigma)**2
     _z_1_e = numpy.where(numpy.isnan(z_sum_e), 0., z_sum_e).sum(axis=1)
     _z_1 = numpy.where(numpy.isnan(z_sum_e), 0., z_sum).sum(axis=1)
-    _z_1_s = numpy.sqrt(numpy.where(numpy.isnan(z_sum_e), 0., z_sum_s_sq).sum(axis=1))
+    _z_1_s = numpy.sqrt(numpy.where(numpy.isnan(z_sum_e), 0., z_sum_s_sq).sum(
+        axis=1))
     _n_1 = numpy.where(numpy.isnan(z_sum_e), 0., 1.).sum(axis=1)
     z_1_sum = _z_1/_n_1
     z_1_sum_e = _z_1_e/_n_1
     z_1_sum_s = _z_1_s/_n_1
 
-
     z_diff = intensity_up_total-intensity_down_total
     z_diff_e = intensity_up-intensity_down
     _z_1_e = numpy.where(numpy.isnan(z_diff_e), 0., z_diff_e).sum(axis=1)
@@ -1119,15 +1234,14 @@ def dock_pd2d_proc(obj:Pd2dProc, l_pd2d_peak: List[Pd2dPeakL]):
     win = pg.GraphicsLayoutWidget()
 
     err_s = pg.ErrorBarItem(x=ttheta, y=z_1_sum_e, top=z_1_sum_s,
-                                      bottom=z_1_sum_s, beam=0.5)
+                            bottom=z_1_sum_s, beam=0.5)
     err_m = pg.ErrorBarItem(x=ttheta, y=z_1_diff_e, top=z_1_diff_s,
-                                      bottom=z_1_diff_s, beam=0.5)
-
+                            bottom=z_1_diff_s, beam=0.5)
 
     win_1d_s = pg.GraphicsLayoutWidget()
     p1 = win_1d_s.addPlot()
     vb_p2 = add_2nd_axis_to_plot(p1, label_axis_1="Intensity (a.u.)",
-                                  label_axis_2="Intensity (a.u.)")
+                                 label_axis_2="Intensity (a.u.)")
     p1.plot(ttheta, z_1_sum_e, symbol='o', pen={'color': 0.8, 'width': 2})
     p1.plot(ttheta, z_1_sum, pen=pg_pen_black)
     p1.addItem(err_s)
@@ -1137,7 +1251,7 @@ def dock_pd2d_proc(obj:Pd2dProc, l_pd2d_peak: List[Pd2dPeakL]):
     win_1d_m = pg.GraphicsLayoutWidget()
     p3 = win_1d_m.addPlot()
     vb_p4 = add_2nd_axis_to_plot(p3, label_axis_1="Intensity (a.u.)",
-                                  label_axis_2="Intensity (a.u.)")
+                                 label_axis_2="Intensity (a.u.)")
     p3.plot(ttheta, z_1_diff_e, symbol='o', pen={'color': 0.8, 'width': 2})
     p3.plot(ttheta, z_1_diff, pen=pg_pen_black)
     p3.addItem(err_m)
@@ -1213,11 +1327,12 @@ def dock_pd2d_proc(obj:Pd2dProc, l_pd2d_peak: List[Pd2dPeakL]):
 def dock_diffrn(obj: Diffrn, thread: QtCore.QThread):
     """Docks for Diffrn objects."""
     docks = []
-    f_setup = obj.setup is not None
-    f_diffrn_radiation = obj.diffrn_radiation is not None
-    f_diffrn_orient_matrix = obj.diffrn_orient_matrix is not None
-    f_diffrn_refln = obj.diffrn_refln is not None
-    f_phase = obj.phase is not None
+
+    f_setup = obj.is_attribute("setup")
+    f_diffrn_radiation = obj.is_attribute("diffrn_radiation")
+    f_diffrn_orient_matrix = obj.is_attribute("diffrn_orient_matrix")
+    f_diffrn_refln = obj.is_attribute("diffrn_refln")
+    f_phase = obj.is_attribute("phase")
     if not(f_setup & f_diffrn_radiation & f_diffrn_orient_matrix &
            f_diffrn_refln & f_phase):
         layout_actions = QtWidgets.QHBoxLayout()
@@ -1316,8 +1431,9 @@ def dock_diffrn(obj: Diffrn, thread: QtCore.QThread):
         docks.append(pg_da.Dock("Diffrn Orient Matrix", widget=widget,
                                 autoOrientation=False))
 
-    f_refine_ls = obj.refine_ls is not None
-    if f_refine_ls:
-        docks.extend(list(dock_refine_ls(obj.refine_ls)))
-
+    try:
+        refine_ls = obj.is_attribute("refine_ls")
+        docks.extend(list(dock_refine_ls(refine_ls)))
+    except AttributeError:
+        pass
     return tuple(docks)
